package com.jz.dmp.modules.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.jz.common.constant.GatewayApiConstant;
import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.common.utils.web.HttpClientUtils;
import com.jz.dmp.modules.controller.dataService.bean.*;
import com.jz.dmp.modules.service.DmpApiMangeService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

/**
 * @ClassName: DmpOrgMangeServiceImpl
 * @Description: 数据服务组织管理
 * @Author: Bellamy
 * @Date 2021/1/15
 * @Version 1.0
 */
@Service("dmpApiMangeService")
public class DmpApiMangeServiceImpl implements DmpApiMangeService {

    private static Logger logger = LoggerFactory.getLogger(DmpApiMangeServiceImpl.class);

    @Value("${spring.gateway-url}")
    private String gatewayUrl;

    /**
     * 授权给他人的API-列表分页查询
     *
     * @author Bellamy
     * @since 2021-01-18
     */
    @Override
    public JsonResult queryApiAuthListPage(AuthListInfoReq req) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.apiAuthListPage;
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(req));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("查询失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                return JsonResult.ok(jsonObject.get("data"));
            }
        }
        if (jsonObject.containsKey("message")) {
            logger.info(jsonObject.get("message").toString());
            result.setMessage(jsonObject.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        }
        return result;
    }

    /**
     * 取消授权
     *
     * @author Bellamy
     * @since 2021-01-18
     */
    @Override
    public JsonResult cancelApiAuth(String id) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.cancelApiAuth;
        Map params = new HashMap();
        params.put("id", id);
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(params));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                return JsonResult.ok(jsonObject.get("data"));
            }
        }
        if (jsonObject.containsKey("message")) {
            logger.info(jsonObject.get("message").toString());
            result.setMessage(jsonObject.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        }
        return result;
    }

    /**
     * 发布的API-API列表分页查询
     *
     * @author Bellamy
     * @since 2021-01-18
     */
    @Override
    public JsonResult queryApiListPage(ApiInterfaceInfoListReq req) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.apiListPage;
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(req));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("查询失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                return JsonResult.ok(jsonObject.get("data"));
            }
        }
        if (jsonObject.containsKey("message")) {
            logger.info(jsonObject.get("message").toString());
            result.setMessage(jsonObject.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        }
        return result;
    }

    /**
     * 删除api
     *
     * @author Bellamy
     * @since 2021-01-18
     */
    @Override
    public JsonResult delApiInfo(String apiKey, String type) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.delApi;
        Map params = new HashMap();
        params.put("apiKey", apiKey);
        params.put("type", type);
        String returnData = HttpClientUtils.getJsonForParam(url, params);
        if (StringUtils.isEmpty(returnData)) {
            throw new RuntimeException("删除失败！");
        }
        logger.info("#################响应结果{}" + returnData);
        Map map = JSONObject.parseObject(returnData);
        if (map.containsKey("code")) {
            if ("200".equals(map.get("code").toString())) {
                return JsonResult.ok();
            }
        }
        if (map.containsKey("message")) {
            logger.info(map.get("message").toString());
            result.setMessage(map.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        }
        return result;
    }

    /**
     * 根据apiid获取API详情
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    @Override
    public JsonResult queryApiInfoByApiId(String id) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.getApiInfo;

        Map params = new HashMap();
        params.put("id", id);
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(params));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("查询失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                return JsonResult.ok(jsonObject.get("data"));
            }
        }
        if (jsonObject.containsKey("message")) {
            logger.info(jsonObject.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            result.setMessage(jsonObject.get("message").toString());
        }
        return result;
    }

    /**
     * 授权给组织-提交保存
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    @Override
    public JsonResult addApiAuthToOrg(AuthUserApiReq req) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.apiAuthToOrg;
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(req));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("保存失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                result.setData(jsonObject.get("data")); //授权码和盐值
                return result;
            }
        }
        if (jsonObject.containsKey("message")) {
            logger.info(jsonObject.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            result.setMessage(jsonObject.get("message").toString());
        }
        return result;
    }

    /**
     * API测试
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    @Override
    public JsonResult apiTestInfo(String apiKey) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.testApi;

        Map params = new HashMap();
        params.put("apiKey", apiKey);
        String returnData = HttpClientUtils.getJsonForParam(url, params);
        if (StringUtils.isEmpty(returnData)) {
            throw new RuntimeException("测试失败！");
        }
        logger.info("#################响应结果{}" + returnData);
        Map map = JSONObject.parseObject(returnData);
        if (map.containsKey("code")) {
            if ("200".equals(map.get("code").toString())) {
                return JsonResult.ok(map.get("data"));
            }
        }
        if (map.containsKey("message")) {
            logger.info(map.get("message").toString());
            result.setMessage(map.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        }
        return result;
    }

    /**
     * 查看日志
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    @Override
    public JsonResult checkApiLogInfo(LogInfoListReq req) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.checkApiLog;
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(req));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("查询失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                result.setData(jsonObject.get("data"));
                return result;
            }
        }
        if (jsonObject.containsKey("message")) {
            logger.info(jsonObject.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            result.setMessage(jsonObject.get("message").toString());
        }
        return result;
    }

    /**
     * 授权模糊查询组织信息
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    @Override
    public JsonResult getAuthOrgList(String key) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.authOrgList;

        Map params = new HashMap();
        params.put("key", key);
        String returnData = HttpClientUtils.getJsonForParam(url, params);
        if (StringUtils.isEmpty(returnData)) {
            throw new RuntimeException("查询失败！");
        }
        logger.info("#################响应结果{}" + returnData);
        Map map = JSONObject.parseObject(returnData);
        if (map.containsKey("code")) {
            if ("200".equals(map.get("code").toString())) {
                return JsonResult.ok(map.get("data"));
            }
        }
        if (map.containsKey("message")) {
            logger.info(map.get("message").toString());
            result.setMessage(map.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        }
        return result;
    }

    /**
     * @param id
     * @param optStatus
     * @Description:服务发布/服务取消
     * @author Bellamy
     * @since 2021-02-07
     */
    @Override
    public JsonResult apiPublishCancel(String id, Boolean optStatus) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.apiPublishCancel;

        Map params = new HashMap();
        params.put("id", id);
        params.put("optStatus", optStatus);
        String returnData = HttpClientUtils.getJsonForParam(url, params);
        if (StringUtils.isEmpty(returnData)) {
            throw new RuntimeException("失败！");
        }
        logger.info("#################响应结果{}" + returnData);
        Map map = JSONObject.parseObject(returnData);
        if (map.containsKey("code")) {
            if ("200".equals(map.get("code").toString())) {
                return JsonResult.ok();
            }
        }
        if (map.containsKey("message")) {
            logger.info(map.get("message").toString());
            result.setMessage(map.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        }
        return result;
    }

    /**
     * 盐值重置
     *
     * @param req
     * @author Bellamy
     * @since 2021-02-20
     */
    @Override
    public JsonResult saltReset(SaltResetReq req) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.saltReset;
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(req));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("查询失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                result.setData(jsonObject.get("data"));
                return result;
            }
        }
        if (jsonObject.containsKey("message")) {
            logger.info(jsonObject.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            result.setMessage(jsonObject.get("message").toString());
        }
        return result;
    }

    /**
     * 授权管理-api列表
     *
     * @param req
     * @author Bellamy
     * @since 2021-02-20
     */
    @Override
    public JsonResult queryAuthApiList(AuthApiListReq req) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.authApiList;
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(req));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("查询失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                result.setData(jsonObject.get("data"));
                return result;
            }
        }
        if (jsonObject.containsKey("message")) {
            logger.info(jsonObject.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            result.setMessage(jsonObject.get("message").toString());
        }
        return result;
    }

    /**
     * 用户授权
     *
     * @param req
     * @author Bellamy
     * @since 2021-02-20
     */
    @Override
    public JsonResult authUserApi(AuthUserApiReq req) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.authUserApi;
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(req));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("查询失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                result.setData(jsonObject.get("data"));
                return result;
            }
        }
        if (jsonObject.containsKey("message")) {
            logger.info(jsonObject.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            result.setMessage(jsonObject.get("message").toString());
        }
        return result;
    }

    /**
     * 服务开发--上传（发送给数据银行）
     *
     * @param id
     * @author Bellamy
     * @since 2021-02-20
     */
    @Override
    public JsonResult serverUpload(String id) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.serverUpload;

        Map params = new HashMap();
        params.put("id", Long.valueOf(id));
        String returnData = HttpClientUtils.getJsonForParam(url, params);
        if (StringUtils.isEmpty(returnData)) {
            throw new RuntimeException("查询失败！");
        }
        logger.info("#################响应结果{}" + returnData);
        Map map = JSONObject.parseObject(returnData);
        if (map.containsKey("code")) {
            if ("200".equals(map.get("code").toString())) {
                return JsonResult.ok();
            }
        }
        if (map.containsKey("message")) {
            logger.info(map.get("message").toString());
            result.setMessage(map.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        }
        return result;
    }

    /**
     * 日志详情
     *
     * @param id
     * @author Bellamy
     * @since 2021-02-20
     */
    @Override
    public JsonResult logDetails(String id) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.logDetails;

        Map params = new HashMap();
        params.put("id", id);
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(params));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("查询失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                return JsonResult.ok(jsonObject.get("data"));
            }
        }
        if (jsonObject.containsKey("message")) {
            logger.info(jsonObject.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            result.setMessage(jsonObject.get("message").toString());
        }
        return result;
    }

}
